/******************************************************************************
* File Name: measurement.h
*  Version 2.0
*
* Description:
*  This file contains the defines and function prototypes for the functions in 
* measurement.c flie.
* 
* Note:
*
********************************************************************************
* Copyright (2015), Cypress Semiconductor Corporation. All Rights Reserved.
********************************************************************************
* This software is owned by Cypress Semiconductor Corporation (Cypress)
* and is protected by and subject to worldwide patent protection (United
* States and foreign), United States copyright laws and international treaty
* provisions. Cypress hereby grants to licensee a personal, non-exclusive,
* non-transferable license to copy, use, modify, create derivative works of,
* and compile the Cypress Source Code and derivative works for the sole
* purpose of creating custom software in support of licensee product to be
* used only in conjunction with a Cypress integrated circuit as specified in
* the applicable agreement. Any reproduction, modification, translation,
* compilation, or representation of this software except as specified above 
* is prohibited without the express written permission of Cypress.
*
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH 
* REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the 
* materials described herein. Cypress does not assume any liability arising out 
* of the application or use of any product or circuit described herein. Cypress 
* does not authorize its products for use as critical components in life-support 
* systems where a malfunction or failure may reasonably be expected to result in 
* significant injury to the user. The inclusion of Cypress' product in a life-
* support systems application implies that the manufacturer assumes all risk of 
* such use and in doing so indemnifies Cypress against all charges. 
*
* Use of this Software may be limited by and subject to the applicable Cypress
* software license agreement. 
*******************************************************************************/
#if !defined(measurement_H)
#define measurement_H

#include "device.h"

/*AMUX channel selections*/
#define AMUX_1_VT 0
#define AMUX_1_VREF 1
#define AMUX_1_CDS 2
#define AMUX_1_BAT_VOLT 3
#define AMUX_1_BAT_AMP 4   
#define AMUX_1_SOL_VOLT 5
#define AMUX_1_SOL_AMP 6  
    
/*Battery Voltages*/
#define BAT_MIN 10.5
#define BAT_MAX 15.0
#define BULK_CH_SP 14.4 // bulk charge set point for sealed lead acid battery
#define FLOAT_CH_SP 13.6  //float charge set point for lead acid battery
#define LVD 11.5 // low voltage disconnect
    
/* Known voltage fed externally for calibration */
#define KNOWN_VOLTAGE 4.2 /* 4.2V */    
    
#define REFERENCE_RESISTOR 10000

/* Function prototype to measure the voltage across resistance */
int32 MeasureResistorVoltage(uint8 channel);
/* Function prototype to measure the battery voltage */
int32 GetVoltage(uint8 channel);
/* Function prototype to measure the battery current */
//int32 GetCurrent(uint8 channel);
#endif
